@@ -20,7 +20,9 @@ def run_command(cmd):
             process = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE)
             output = process.communicate()
             if process.returncode != 0:
-                exit("{}: Process exited with error".format(cmd))
+                WARNING = '\033[93m'
+                FAIL = '\033[91m'
+                exit(WARNING + "ERROR: snprocess unable to run. Is plink installed?\nhttps://www.cog-genomics.org/plink/1.9/" + FAIL + "\n\n{}\n^^^ Process exited with error".format(cmd))
             return str(output).split("\\n")
 
 
@@ -75,4 +77,4 @@ def sort_unique(outDir: str, fn1: str, fn2: str) -> pd.DataFrame:
     file2 = read_snp_data(outDir, fn2)
     output = pd.concat([file1, file2])
     output = output.drop_duplicates(keep=False)
-    return output
\ No newline at end of file
+    return output
